# Chilkat .NET Core Classes for .NET Core 3.1 and later

The .NET Core assembly is cross-platform and runs on Windows, Linux, and macOS. This makes it suitable for desktop and ASP.NET Core applications, cross-platform console applications, and cloud services.
(Most applications should reference the "ChilkatDnCore" package, for .NET 6.0 and later.)

## About the Chilkat Library

The **Chilkat .NET library** is a comprehensive suite of software components that provide a wide range of functionality for use in .NET applications. These components are primarily focused on internet communications and cryptographic operations, making it easier for developers to handle tasks such as email processing, data encryption, file transfer protocols, and various internet-based services.

Here are some key features of the Chilkat .NET library:

#### 1\. **Email and POP3/SMTP/IMAP Functionality**

*   Sending and receiving emails through SMTP, POP3, and IMAP protocols.
*   Handling email attachments, multipart emails, and HTML emails.
*   Support for secure email communication via SSL/TLS.
*   Advanced email features such as signing, verifying, encrypting, and decrypting emails using S/MIME.

#### 2\. **File Transfer Protocols**

*   Support for FTP, FTPS (FTP over SSL), and SFTP (SSH File Transfer Protocol).
*   Automates file uploads, downloads, and directory manipulation on remote servers.
*   Supports large file transfers and background transfers.

#### 3\. **Encryption and Cryptography**

*   Symmetric encryption (AES, DES, Triple DES, Blowfish, etc.).
*   Public-key cryptography (RSA, ECDSA, DSA).
*   Hashing algorithms (SHA1, SHA256, SHA384, SHA512, MD5, etc.).
*   Digital signatures and verification.
*   Signing PDF files
*   XML Digital Signatures (XMLDsig/XAdES)
*   Cloud-based Signing including integrated support for the Cloud Signature Consortium (CSC) standard.
*   Smartcard and USB token cryptographic operations via PCKS11, ScMiniDriver, MS CNG, and Apple Keychain (on MacOS)

#### 4\. **Web Services and Internet Protocols**

*   HTTP and HTTPS requests for web services, including handling cookies, custom headers, and authentication.
*   SOAP and REST web service client support.
*   WebSocket support.

#### 5\. **Compression**

*   File compression and decompression support (ZIP, GZip, etc.).
*   Securely handle large files and streams.

#### 6\. **Authentication and Security**

*   Provides functionality for OAuth2 authentication.
*   Support for TLS/SSL client and server certificates.
*   Integrated with security standards like SSH and SSL/TLS.

#### 7\. **Cloud and API Integration**

*   Includes APIs for integration with cloud services such as Amazon S3, Google Cloud Storage, and Microsoft Azure.
*   Support for uploading, downloading, and managing cloud storage files.

#### 8\. **Cross-Platform and Version Support**

*   Works with .NET Framework and .NET Core.
*   Also available for use in other languages, such as C++, Python, Java, and more.
*   Online code generation tools to assist with development at https://tools.chilkat.io/

#### **Why Use Chilkat?**

*   **Ease of use**: Chilkat simplifies complex internet-based protocols and cryptographic operations into straightforward APIs.
*   **Reliability**: The library is widely used in industry and has a reputation for being robust and well-maintained.
*   **Comprehensive documentation**: The library comes with detailed documentation and example code for various tasks.

#### **Typical Use Cases**

*   Sending/receiving emails in .NET applications.
*   Secure file transfers between servers.
*   Interacting with web APIs and services.
*   Encrypting/decrypting sensitive data.
*   Performing secure authentication and handling digital signatures.

Chilkat is popular among developers who need a reliable and comprehensive solution for handling a variety of network communications and security tasks in their .NET applications.

